@@ -7,7 +7,7 @@ from whatap.util.userid_util import UseridUtil as userid_util
 import whatap.util.bit_util as bit_util
 from whatap.conf.configure import Configure as conf
 from whatap.util.date_util import DateUtil
-from whatap.net.udp_session import UdpSession
+import whatap.net.async_sender as async_sender
 from whatap.net.packet_type_enum import PacketTypeEnum
 from whatap.util.hash_util import HashUtil as hash_util
 from whatap.util.hexa32 import Hexa32 as hexa32
@@ -78,7 +78,7 @@ def sendHeaders(ctx, environ):
     
     datas = ['HTTP-HEADERS', 'HTTP-HEADERS', text]
     ctx.start_time = DateUtil.nowSystem()
-    UdpSession.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
+    async_sender.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
 
 def setUserId(environ, res, cookieValue):
     try:
